# Bugs and contributions

If you find any bugs in beancount2ledger or believe the conversion from beancount to ledger could be improved, please [open an issue](https://github.com/beancount/beancount2ledger/issues).  Please include a small test case so we can reproduce the problem.

If you'd like to contribute code to beancount2ledger, please submit a [pull request on GitHub](https://github.com/beancount/beancount2ledger/pulls).

Please make sure you add a test case and update the documentation (`docs/`, and possibly `README.md`).

